import { Transaction } from '@sentry/types';
import { record } from 'rrweb';
import type { eventWithTime } from 'rrweb/typings/types';
import { ReplayPerformanceEntry } from './createPerformanceEntry';
declare type RRWebEvent = eventWithTime;
declare type RRWebOptions = Parameters<typeof record>[0];
interface PluginOptions {
    /**
     * The amount of time to wait before sending a replay
     */
    uploadMinDelay?: number;
    /**
     * The max amount of time to wait before sending a replay
     */
    uploadMaxDelay?: number;
    /**
     * If false, will create a new session per pageload
     */
    stickySession?: boolean;
}
interface SentryReplayConfiguration extends PluginOptions {
    /**
     * Options for `rrweb.record`
     */
    rrwebConfig?: RRWebOptions;
}
export declare class SentryReplay {
    /**
     * @inheritDoc
     */
    static id: string;
    /**
     * @inheritDoc
     */
    name: string;
    /**
     * Buffer of rrweb events that will be serialized as JSON and saved as an attachment to a Sentry event
     */
    events: RRWebEvent[];
    performanceEvents: PerformanceEntry[];
    /**
     * A Sentry Transaction that should capture every incremental rrweb update,
     * but *not* the attachments themselves. This is currently used to capture
     * breadcrumbs and maybe other spans (e.g. network requests)
     */
    private replayEvent;
    /**
     * Options to pass to `rrweb.record()`
     */
    private readonly rrwebRecordOptions;
    private readonly options;
    /**
     * setTimeout id used for debouncing sending rrweb attachments
     */
    private timeout;
    /**
     * The timestamp of the first event since the last flush.
     * This is used to determine if the maximum allowed time has passed before we should flush events again.
     */
    private initialEventTimestampSinceFlush;
    private performanceObserver;
    private session;
    private static attachmentUrlFromDsn;
    /**
     * Get integration's instance on the current hub
     */
    private get instance();
    constructor({ uploadMinDelay, uploadMaxDelay, stickySession, // TBD: Making this opt-in for now
    rrwebConfig: { maskAllInputs, ...rrwebRecordOptions }, }?: SentryReplayConfiguration);
    setupOnce(): void;
    /**
     * Loads a session from storage, or creates a new one
     */
    loadSession({ expiry }: {
        expiry: number;
    }): void;
    addListeners(): void;
    /**
     * Keep a list of performance entries that will be sent with a replay
     */
    handlePerformanceObserver: (list: PerformanceObserverEntryList) => void;
    /**
     * Handle when visibility of the page changes. (e.g. new tab is opened)
     */
    handleVisibilityChange: () => void;
    /**
     * Trigger rrweb to take a full snapshot which will cause this plugin to
     * create a new Replay event.
     */
    triggerFullSnapshot(): void;
    /**
     * This is our pseudo replay event disguised as a transaction. It will be
     * used to store performance entries and breadcrumbs for every incremental
     * replay event.
     **/
    createReplayEvent(): Transaction;
    /**
     * Create a span for each performance entry. The parent transaction is `this.replayEvent`.
     */
    createPerformanceSpans(entries: ReplayPerformanceEntry[]): void;
    /**
     * Observed performance events are added to `this.performanceEvents`. These
     * are included in the replay event before it is finished and sent to Sentry.
     */
    addPerformanceEntries(): void;
    finishReplayEvent(): void;
    /**
     * Determine if there is browser support for `navigator.sendBeacon`
     */
    hasSendBeacon(): boolean;
    /**
     * Send replay attachment using either `sendBeacon()` or `fetch()`
     */
    sendReplayRequest(endpoint: string, events: RRWebEvent[]): Promise<void>;
    /**
     * Finalize and send the current replay event to Sentry
     */
    sendReplay(eventId: string): Promise<boolean>;
}
export {};
